import { createRenderer } from "@vue/runtime-core";
import { Graphics, Text, Container, Sprite, Texture } from "pixi.js";

// 创建渲染器
const renderer = createRenderer({
  // 实现渲染接口
  createElement(type) {
    let element;
    // 基于 type 去创建视图
    switch (type) {
      case "Container":
        element = new Container();
        break;
      case "Sprite":
        element = new Sprite();
        break;
    }
    return element;
  },
  insert(el, parent) {
    console.log("==========> insert start <==========");
    parent.addChild(el);
    console.log(el);
    console.log(parent);
    console.log("==========> insert end <==========");
  },
  patchProp(el, key, prevValue, nextValue) {
    console.log("==========> patch prop start <==========");
    console.log(el)
    console.log(key)
    console.log(prevValue)
    console.log(nextValue)
    switch (key) {
      case "texture":
        el.texture = Texture.from(nextValue);
        break;
      case "onClick":
        // 给pixi元素注册点击事件
        el.on("pointertap", nextValue);
        break;
      default:
        el[key] = nextValue;
    }
    console.log("==========> patch prop end <==========");
  },
  setElementText(node, text) {
    const canvasText = new Text(text);
    node.addChild(canvasText);
  },
  createText(text) {
    // console.log(text)
    return new Text(text);
  },
  // 处理注释
  createComment() {},
  // 获取父节点
  parentNode(node) {
    console.log("==========> parent node start <==========");
    console.log(node);
    console.log("==========> parent node end <==========");
  },
  // 获取兄弟节点
  nextSibling() {},
  // 删除节点时调用
  remove(el) {
    console.log("==========> remove start <==========");
    const parent = el.parent;
    if (parent) {
      parent.removeChild(el);
    }
    console.log("==========> remove end <==========");
  },
});
// console.log(renderer)

export function createApp(rootComponent) {
  // 调用 renderer
  return renderer.createApp(rootComponent);
}
